Module perf_insight

Module perf_insight 

Offline analysis of Chrome Tracing event dumps produced by perf stop.

Input formats supported:

  • NDJSON lines, each an array of trace events
  • A single JSON array of events
  • Nested arrays from Tracing.dataCollected value payloads

Functions

analyze_file
Analyze a trace file written by perf stop (NDJSON of event arrays).
analyze_text
Analyze in-memory NDJSON / JSON chunks joined with newlines.