Typed CLI errors and exit codes. Typed CLI errors with sysexits-style exit codes.
Error kinds
ErrorKind maps to process exit codes used by the binary and JSON envelopes.
Examples
use browser_automation_cli::error::{CliError, ErrorKind};
let err = CliError::with_suggestion(
ErrorKind::Unavailable,
"chrome not found",
"install Chromium or Google Chrome",
);
assert_eq!(err.exit_code(), 69);
assert_eq!(err.kind().as_str(), "unavailable");Structs
- CliError
- Typed CLI error with optional remediation hint.
Enums
- Error
Kind - High-level failure category mapped to a process exit code.