pub struct ClickResult {
pub dialog_opened: bool,
pub pending_release: Option<PendingRelease>,
}Expand description
Outcome of a click. dialog_opened is true if a JavaScript dialog opened
mid-sequence (the page is then blocked until dialog accept/dismiss).
pending_release is set only when the dialog opened after mousePressed but
before mouseReleased: the button is logically held until the caller
dispatches the release (done once the dialog is resolved), otherwise the
next click would register as a drag or double-click.
Fields
dialog_opened: boolpending_release: Option<PendingRelease>Trait Implementations
Sourceimpl Default for ClickResult
impl Default for ClickResult
Sourcefn default() -> ClickResult
fn default() -> ClickResult
Returns the “default value” for a type. Read more